@@ -43,41 +43,29 @@
 # USE OR OTHER DEALINGS IN THE SOFTWARE.
 ##############################################################################
 
-from __future__ import print_function, division
-import os
-from datetime import date
 import gzip
-import numpy as np
-import xml.etree.ElementTree as etree
-from copy import copy, deepcopy
-from mdtraj.formats.pdb.pdbstructure import PdbStructure
-from mdtraj.core.topology import Topology
-from mdtraj.utils import ilen, cast_indices, in_units_of, open_maybe_zipped
-from mdtraj.formats.registry import FormatRegistry
-from mdtraj.core import element as elem
-from mdtraj.utils import six
-from mdtraj import version
+import os
 import warnings
-if six.PY3:
-    from urllib.request import urlopen
-    from urllib.parse import urlparse
-    from urllib.parse import (uses_relative, uses_netloc, uses_params)
-else:
-    from urllib2 import urlopen
-    from urlparse import urlparse
-    from urlparse import uses_relative, uses_netloc, uses_params
-    # Ugly hack -- we don't always issue UserWarning in Py2, but we need to in
-    # this module
-    warnings.filterwarnings('always', category=UserWarning, module=__name__)
+import xml.etree.ElementTree as etree
+from copy import copy
+from datetime import date
+from io import StringIO
+from urllib.parse import urlparse, uses_netloc, uses_params, uses_relative
+from urllib.request import urlopen
+
+import numpy as np
+
+from mdtraj import version
+from mdtraj.core import element as elem
+from mdtraj.core.topology import Topology
+from mdtraj.formats.pdb.pdbstructure import PdbStructure
+from mdtraj.formats.registry import FormatRegistry
+from mdtraj.utils import cast_indices, ilen, in_units_of, open_maybe_zipped
 
 _VALID_URLS = set(uses_relative + uses_netloc + uses_params)
-_VALID_URLS.discard('')
+_VALID_URLS.discard("")
 
-__all__ = ['load_pdb', 'PDBTrajectoryFile']
-
-##############################################################################
-# Code
-##############################################################################
+__all__ = ["load_pdb", "PDBTrajectoryFile"]
 
 
 def _is_url(url):
@@ -91,10 +79,17 @@ def _is_url(url):
         return False
 
 
-@FormatRegistry.register_loader('.pdb')
-@FormatRegistry.register_loader('.pdb.gz')
-def load_pdb(filename, stride=None, atom_indices=None, frame=None,
-             no_boxchk=False, standard_names=True, top=None):
+@FormatRegistry.register_loader(".pdb")
+@FormatRegistry.register_loader(".pdb.gz")
+def load_pdb(
+    filename,
+    stride=None,
+    atom_indices=None,
+    frame=None,
+    no_boxchk=False,
+    standard_names=True,
+    top=None,
+):
     """Load a RCSB Protein Data Bank file from disk.
 
     Parameters
@@ -146,9 +141,11 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
     mdtraj.PDBTrajectoryFile : Low level interface to PDB files
     """
     from mdtraj import Trajectory
-    if not isinstance(filename, (six.string_types, os.PathLike)):
-        raise TypeError('filename must be of type string or path-like for load_pdb. '
-            'you supplied %s' % type(filename))
+
+    if not isinstance(filename, (str, os.PathLike)):
+        raise TypeError(
+            "filename must be of type string or path-like for load_pdb. " "you supplied %s" % type(filename),
+        )
 
     atom_indices = cast_indices(atom_indices)
 
@@ -158,7 +155,7 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
             coords = f.positions[[frame], atom_slice, :]
         else:
             coords = f.positions[::stride, atom_slice, :]
-        assert coords.ndim == 3, 'internal shape error'
+        assert coords.ndim == 3, "internal shape error"
         n_frames = len(coords)
 
         topology = f.topology
@@ -175,7 +172,12 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
             unitcell_angles = None
 
         in_units_of(coords, f.distance_unit, Trajectory._distance_unit, inplace=True)
-        in_units_of(unitcell_lengths, f.distance_unit, Trajectory._distance_unit, inplace=True)
+        in_units_of(
+            unitcell_lengths,
+            f.distance_unit,
+            Trajectory._distance_unit,
+            inplace=True,
+        )
 
     time = np.arange(len(coords))
     if frame is not None:
@@ -183,9 +185,13 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
     elif stride is not None:
         time *= stride
 
-    traj = Trajectory(xyz=coords, time=time, topology=topology,
-                      unitcell_lengths=unitcell_lengths,
-                      unitcell_angles=unitcell_angles)
+    traj = Trajectory(
+        xyz=coords,
+        time=time,
+        topology=topology,
+        unitcell_lengths=unitcell_lengths,
+        unitcell_angles=unitcell_angles,
+    )
 
     if not no_boxchk and traj.unitcell_lengths is not None:
         # Only one CRYST1 record is allowed, so only do this check for the first
@@ -197,16 +203,20 @@ def load_pdb(filename, stride=None, atom_indices=None, frame=None,
         # to say that no particle density should exceed 10x that.
         particle_density = traj.top.n_atoms / traj.unitcell_volumes[0]
         if particle_density > 1000:
-            warnings.warn('Unlikely unit cell vectors detected in PDB file likely '
-                          'resulting from a dummy CRYST1 record. Discarding unit '
-                          'cell vectors.', category=UserWarning)
+            warnings.warn(
+                "Unlikely unit cell vectors detected in PDB file likely "
+                "resulting from a dummy CRYST1 record. Discarding unit "
+                "cell vectors.",
+                category=UserWarning,
+            )
             traj._unitcell_lengths = traj._unitcell_angles = None
 
     return traj
 
-@FormatRegistry.register_fileobject('.pdb')
-@FormatRegistry.register_fileobject('.pdb.gz')
-class PDBTrajectoryFile(object):
+
+@FormatRegistry.register_fileobject(".pdb")
+@FormatRegistry.register_fileobject(".pdb.gz")
+class PDBTrajectoryFile:
     """Interface for reading and writing Protein Data Bank (PDB) files
 
     Parameters
@@ -243,12 +253,20 @@ class PDBTrajectoryFile(object):
     --------
     mdtraj.load_pdb : High-level wrapper that returns a ``md.Trajectory``
     """
-    distance_unit = 'angstroms'
+
+    distance_unit = "angstroms"
     _residueNameReplacements = {}
     _atomNameReplacements = {}
-    _chain_names = [chr(ord('A') + i) for i in range(26)]
+    _chain_names = [chr(ord("A") + i) for i in range(26)]
 
-    def __init__(self, filename, mode='r', force_overwrite=True, standard_names=True, top=None):
+    def __init__(
+        self,
+        filename,
+        mode="r",
+        force_overwrite=True,
+        standard_names=True,
+        top=None,
+    ):
         self._open = False
         self._file = None
         self._topology = top
@@ -257,34 +275,36 @@ class PDBTrajectoryFile(object):
         self._last_topology = None
         self._standard_names = standard_names
 
-        if mode == 'r':
+        if mode == "r":
             PDBTrajectoryFile._loadNameReplacementTables()
 
             if _is_url(filename):
                 self._file = urlopen(filename)
-                if filename.lower().endswith('.gz'):
-                    if six.PY3:
-                        self._file = gzip.GzipFile(fileobj=self._file)
-                    else:
-                        self._file = gzip.GzipFile(fileobj=six.StringIO(
-                            self._file.read()))
-                if six.PY3:
-                    self._file = six.StringIO(self._file.read().decode('utf-8'))
+                if filename.lower().endswith(".gz"):
+                    self._file = gzip.GzipFile(fileobj=self._file)
+                self._file = StringIO(self._file.read().decode("utf-8"))
             else:
-                self._file = open_maybe_zipped(filename, 'r')
+                self._file = open_maybe_zipped(filename, "r")
 
             self._read_models()
-        elif mode == 'w':
+        elif mode == "w":
             self._header_written = False
             self._footer_written = False
-            self._file = open_maybe_zipped(filename, 'w', force_overwrite)
+            self._file = open_maybe_zipped(filename, "w", force_overwrite)
         else:
             raise ValueError("invalid mode: %s" % mode)
 
         self._open = True
 
-    def write(self, positions, topology, modelIndex=None, unitcell_lengths=None,
-              unitcell_angles=None, bfactors=None):
+    def write(
+        self,
+        positions,
+        topology,
+        modelIndex=None,
+        unitcell_lengths=None,
+        unitcell_angles=None,
+        bfactors=None,
+    ):
         """Write a PDB file to disk
 
         Parameters
@@ -304,47 +324,53 @@ class PDBTrajectoryFile(object):
             Save bfactors with pdb file. Should contain a single number for
             each atom in the topology
         """
-        if not self._mode == 'w':
-            raise ValueError('file not opened for writing')
+        if not self._mode == "w":
+            raise ValueError("file not opened for writing")
         if not self._header_written:
             self._write_header(unitcell_lengths, unitcell_angles)
             self._header_written = True
 
         if ilen(topology.atoms) != len(positions):
-            raise ValueError('The number of positions must match the number of atoms')
+            raise ValueError("The number of positions must match the number of atoms")
         if np.any(np.isnan(positions)):
-            raise ValueError('Particle position is NaN')
+            raise ValueError("Particle position is NaN")
         if np.any(np.isinf(positions)):
-            raise ValueError('Particle position is infinite')
+            raise ValueError("Particle position is infinite")
 
-        self._last_topology = topology  # Hack to save the topology of the last frame written, allows us to output CONECT entries in write_footer()
+        # Hack to save the topology of the last frame written, allows us to
+        # output CONECT entries in write_footer()
+        self._last_topology = topology
 
         if bfactors is None:
-            bfactors = ['{0:5.2f}'.format(0.0)] * len(positions)
+            bfactors = [f"{0.0:5.2f}"] * len(positions)
         else:
             if (np.max(bfactors) >= 100) or (np.min(bfactors) <= -10):
                 raise ValueError("bfactors must be in (-10, 100)")
 
-            bfactors = ['{0:5.2f}'.format(b) for b in bfactors]
+            bfactors = [f"{b:5.2f}" for b in bfactors]
 
         atomIndex = 1
         posIndex = 0
         if modelIndex is not None:
             print("MODEL     %4d" % modelIndex, file=self._file)
-        for (chainIndex, chain) in enumerate(topology.chains):
+        for chainIndex, chain in enumerate(topology.chains):
             if not chain.chain_id:
                 chainName = self._chain_names[chainIndex % len(self._chain_names)]
             else:
                 chainName = chain.chain_id[0:1]
             residues = list(chain.residues)
-            for (resIndex, res) in enumerate(residues):
+            for resIndex, res in enumerate(residues):
                 if len(res.name) > 3:
                     resName = res.name[:3]
                 else:
                     resName = res.name
                 for atom in res.atoms:
-                    if len(atom.name) < 4 and atom.name[:1].isalpha() and (atom.element is None or len(atom.element.symbol) < 2):
-                        atomName = ' '+atom.name
+                    if (
+                        len(atom.name) < 4
+                        and atom.name[:1].isalpha()
+                        and (atom.element is None or len(atom.element.symbol) < 2)
+                    ):
+                        atomName = " " + atom.name
                     elif len(atom.name) > 4:
                         atomName = atom.name[:4]
                     else:
@@ -353,24 +379,38 @@ class PDBTrajectoryFile(object):
                     if atom.element is not None:
                         symbol = atom.element.symbol
                     else:
-                        symbol = ' '
+                        symbol = " "
                     if atom.serial is not None and len(topology._chains) < 2:
                         # We can't do this for more than 1 chain
                         # to prevent issue 1611
                         atomSerial = atom.serial
                     else:
                         atomSerial = atomIndex
-                    line = "ATOM  %5d %-4s %3s %1s%4d    %s%s%s  1.00 %5s      %-4s%2s  " % ( # Right-justify atom symbol
-                        atomSerial % 100000, atomName, resName, chainName,
-                        (res.resSeq) % 10000, _format_83(coords[0]),
-                        _format_83(coords[1]), _format_83(coords[2]),
-                        bfactors[posIndex], atom.segment_id[:4], symbol[-2:])
-                    assert len(line) == 80, 'Fixed width overflow detected'
+                    line = (
+                        "ATOM  %5d %-4s %3s %1s%4d    %s%s%s  1.00 %5s      %-4s%2s  "
+                        % (  # Right-justify atom symbol
+                            atomSerial % 100000,
+                            atomName,
+                            resName,
+                            chainName,
+                            (res.resSeq) % 10000,
+                            _format_83(coords[0]),
+                            _format_83(coords[1]),
+                            _format_83(coords[2]),
+                            bfactors[posIndex],
+                            atom.segment_id[:4],
+                            symbol[-2:],
+                        )
+                    )
+                    assert len(line) == 80, "Fixed width overflow detected"
                     print(line, file=self._file)
                     posIndex += 1
                     atomIndex += 1
-                if resIndex == len(residues)-1:
-                    print("TER   %5d      %3s %s%4d" % (atomSerial+1, resName, chainName, res.resSeq), file=self._file)
+                if resIndex == len(residues) - 1:
+                    print(
+                        "TER   %5d      %3s %s%4d" % (atomSerial + 1, resName, chainName, res.resSeq),
+                        file=self._file,
+                    )
                     atomIndex += 1
 
         if modelIndex is not None:
@@ -387,44 +427,85 @@ class PDBTrajectoryFile(object):
             The angles between the three unitcell vectors, ``alpha``,
             ``beta``, ``gamma``
         """
-        if not self._mode == 'w':
-            raise ValueError('file not opened for writing')
+        if not self._mode == "w":
+            raise ValueError("file not opened for writing")
 
         if unitcell_lengths is None and unitcell_angles is None:
             return
         if unitcell_lengths is not None and unitcell_angles is not None:
             if not len(unitcell_lengths) == 3:
-                raise ValueError('unitcell_lengths must be length 3')
+                raise ValueError("unitcell_lengths must be length 3")
             if not len(unitcell_angles) == 3:
-                raise ValueError('unitcell_angles must be length 3')
+                raise ValueError("unitcell_angles must be length 3")
         else:
-            raise ValueError('either unitcell_lengths and unitcell_angles'
-                             'should both be spefied, or neither')
+            raise ValueError(
+                "either unitcell_lengths and unitcell_angles" "should both be spefied, or neither",
+            )
 
         box = list(unitcell_lengths) + list(unitcell_angles)
         assert len(box) == 6
 
         if write_metadata:
-            print("REMARK   1 CREATED WITH MDTraj %s, %s" % (version.version, str(date.today())), file=self._file)
-        print("CRYST1%9.3f%9.3f%9.3f%7.2f%7.2f%7.2f P 1           1 " % tuple(box), file=self._file)
+            print(
+                f"REMARK   1 CREATED WITH MDTraj {version.version}, {str(date.today())}",
+                file=self._file,
+            )
+        print(
+            "CRYST1{:9.3f}{:9.3f}{:9.3f}{:7.2f}{:7.2f}{:7.2f} P 1           1 ".format(*tuple(box)),
+            file=self._file,
+        )
 
     def _write_footer(self):
-        if not self._mode == 'w':
-            raise ValueError('file not opened for writing')
+        if not self._mode == "w":
+            raise ValueError("file not opened for writing")
 
         # Identify bonds that should be listed as CONECT records.
-        standardResidues = ['ALA', 'ASN', 'CYS', 'GLU', 'HIS', 'LEU', 'MET', 'PRO', 'THR', 'TYR',
-                            'ARG', 'ASP', 'GLN', 'GLY', 'ILE', 'LYS', 'PHE', 'SER', 'TRP', 'VAL',
-                            'A', 'G', 'C', 'U', 'I', 'DA', 'DG', 'DC', 'DT', 'DI', 'HOH']
+        standardResidues = [
+            "ALA",
+            "ASN",
+            "CYS",
+            "GLU",
+            "HIS",
+            "LEU",
+            "MET",
+            "PRO",
+            "THR",
+            "TYR",
+            "ARG",
+            "ASP",
+            "GLN",
+            "GLY",
+            "ILE",
+            "LYS",
+            "PHE",
+            "SER",
+            "TRP",
+            "VAL",
+            "A",
+            "G",
+            "C",
+            "U",
+            "I",
+            "DA",
+            "DG",
+            "DC",
+            "DT",
+            "DI",
+            "HOH",
+        ]
         conectBonds = []
         if self._last_topology is not None:
             for atom1, atom2 in self._last_topology.bonds:
                 if atom1.residue.name not in standardResidues or atom2.residue.name not in standardResidues:
                     conectBonds.append((atom1, atom2))
-                elif atom1.name == 'SG' and atom2.name == 'SG' and atom1.residue.name == 'CYS' and atom2.residue.name == 'CYS':
+                elif (
+                    atom1.name == "SG"
+                    and atom2.name == "SG"
+                    and atom1.residue.name == "CYS"
+                    and atom2.residue.name == "CYS"
+                ):
                     conectBonds.append((atom1, atom2))
         if len(conectBonds) > 0:
-
             # Work out the index used in the PDB file for each atom.
 
             atomIndex = {}
@@ -456,7 +537,10 @@ class PDBTrajectoryFile(object):
             for index1 in sorted(atomBonds):
                 bonded = atomBonds[index1]
                 while len(bonded) > 4:
-                    print("CONECT%5d%5d%5d%5d" % (index1, bonded[0], bonded[1], bonded[2]), file=self._file)
+                    print(
+                        "CONECT%5d%5d%5d%5d" % (index1, bonded[0], bonded[1], bonded[2]),
+                        file=self._file,
+                    )
                     del bonded[:4]
                 line = "CONECT%5d" % index1
                 for index2 in bonded:
@@ -480,20 +564,18 @@ class PDBTrajectoryFile(object):
             cycle through to choose chain names.
         """
         for item in values:
-            if not isinstance(item, six.string_types) and len(item) == 1:
-                raise TypeError('Names must be a single character string')
+            if not isinstance(item, str) and len(item) == 1:
+                raise TypeError("Names must be a single character string")
         cls._chain_names = values
 
     @property
     def positions(self):
-        """The cartesian coordinates of all of the atoms in each frame. Available when a file is opened in mode='r'
-        """
+        """The cartesian coordinates of all of the atoms in each frame. Available when a file is opened in mode='r'"""
         return self._positions
 
     @property
     def topology(self):
-        """The topology from this PDB file. Available when a file is opened in mode='r'
-        """
+        """The topology from this PDB file. Available when a file is opened in mode='r'"""
         return self._topology
 
     @property
@@ -513,19 +595,18 @@ class PDBTrajectoryFile(object):
 
     def close(self):
         "Close the PDB file"
-        if self._mode == 'w' and not self._footer_written:
+        if self._mode == "w" and not self._footer_written:
             self._write_footer()
         if self._open:
             self._file.close()
         self._open = False
 
     def _read_models(self):
-        if not self._mode == 'r':
-            raise ValueError('file not opened for reading')
+        if not self._mode == "r":
+            raise ValueError("file not opened for reading")
 
         pdb = PdbStructure(self._file, load_all_models=True)
 
-
         # load all of the positions (from every model)
         _positions = []
         for model in pdb.iter_models(use_all_models=True):
@@ -537,7 +618,9 @@ class PDBTrajectoryFile(object):
             _positions.append(coords)
 
         if not all(len(f) == len(_positions[0]) for f in _positions):
-            raise ValueError('PDB Error: All MODELs must contain the same number of ATOMs')
+            raise ValueError(
+                "PDB Error: All MODELs must contain the same number of ATOMs",
+            )
 
         self._positions = np.array(_positions)
 
@@ -545,7 +628,6 @@ class PDBTrajectoryFile(object):
         self._unitcell_lengths = pdb.get_unit_cell_lengths()
         self._unitcell_angles = pdb.get_unit_cell_angles()
 
-
         # Load the topology if None is given
         if self._topology is None:
             self._topology = Topology()
@@ -557,7 +639,12 @@ class PDBTrajectoryFile(object):
                     resName = residue.get_name()
                     if resName in PDBTrajectoryFile._residueNameReplacements and self._standard_names:
                         resName = PDBTrajectoryFile._residueNameReplacements[resName]
-                    r = self._topology.add_residue(resName, c, residue.number, residue.segment_id)
+                    r = self._topology.add_residue(
+                        resName,
+                        c,
+                        residue.number,
+                        residue.segment_id,
+                    )
                     if resName in PDBTrajectoryFile._atomNameReplacements and self._standard_names:
                         atomReplacements = PDBTrajectoryFile._atomNameReplacements[resName]
                     else:
@@ -569,12 +656,20 @@ class PDBTrajectoryFile(object):
                         atomName = atomName.strip()
                         element = atom.element
                         if element is None:
-                            element = PDBTrajectoryFile._guess_element(atomName, residue.name, len(residue))
+                            element = PDBTrajectoryFile._guess_element(
+                                atomName,
+                                residue.name,
+                                len(residue),
+                            )
 
-                        newAtom = self._topology.add_atom(atomName, element, r, serial=atom.serial_number)
+                        newAtom = self._topology.add_atom(
+                            atomName,
+                            element,
+                            r,
+                            serial=atom.serial_number,
+                        )
                         atomByNumber[atom.serial_number] = newAtom
 
-        
             self._topology.create_standard_bonds()
             self._topology.create_disulfide_bonds(self.positions[0])
 
@@ -587,7 +682,7 @@ class PDBTrajectoryFile(object):
                         connectBonds.append((atomByNumber[i], atomByNumber[j]))
             if len(connectBonds) > 0:
                 # Only add bonds that don't already exist.
-                existingBonds = set(self._topology.bonds)
+                existingBonds = {(bond.atom1, bond.atom2) for bond in self._topology.bonds}
                 for bond in connectBonds:
                     if bond not in existingBonds and (bond[1], bond[0]) not in existingBonds:
                         self._topology.add_bond(bond[0], bond[1])
@@ -597,31 +692,33 @@ class PDBTrajectoryFile(object):
     def _loadNameReplacementTables():
         """Load the list of atom and residue name replacements."""
         if len(PDBTrajectoryFile._residueNameReplacements) == 0:
-            tree = etree.parse(os.path.join(os.path.dirname(__file__), 'data', 'pdbNames.xml'))
+            tree = etree.parse(
+                os.path.join(os.path.dirname(__file__), "data", "pdbNames.xml"),
+            )
             allResidues = {}
             proteinResidues = {}
             nucleicAcidResidues = {}
-            for residue in tree.getroot().findall('Residue'):
-                name = residue.attrib['name']
-                if name == 'All':
+            for residue in tree.getroot().findall("Residue"):
+                name = residue.attrib["name"]
+                if name == "All":
                     PDBTrajectoryFile._parseResidueAtoms(residue, allResidues)
-                elif name == 'Protein':
+                elif name == "Protein":
                     PDBTrajectoryFile._parseResidueAtoms(residue, proteinResidues)
-                elif name == 'Nucleic':
+                elif name == "Nucleic":
                     PDBTrajectoryFile._parseResidueAtoms(residue, nucleicAcidResidues)
             for atom in allResidues:
                 proteinResidues[atom] = allResidues[atom]
                 nucleicAcidResidues[atom] = allResidues[atom]
-            for residue in tree.getroot().findall('Residue'):
-                name = residue.attrib['name']
+            for residue in tree.getroot().findall("Residue"):
+                name = residue.attrib["name"]
                 for id in residue.attrib:
-                    if id == 'name' or id.startswith('alt'):
+                    if id == "name" or id.startswith("alt"):
                         PDBTrajectoryFile._residueNameReplacements[residue.attrib[id]] = name
-                if 'type' not in residue.attrib:
+                if "type" not in residue.attrib:
                     atoms = copy(allResidues)
-                elif residue.attrib['type'] == 'Protein':
+                elif residue.attrib["type"] == "Protein":
                     atoms = copy(proteinResidues)
-                elif residue.attrib['type'] == 'Nucleic':
+                elif residue.attrib["type"] == "Nucleic":
                     atoms = copy(nucleicAcidResidues)
                 else:
                     atoms = copy(allResidues)
@@ -633,21 +730,21 @@ class PDBTrajectoryFile(object):
         "Try to guess the element name"
 
         upper = atom_name.upper()
-        if upper.startswith('CL'):
+        if upper.startswith("CL"):
             element = elem.chlorine
-        elif upper.startswith('NA'):
+        elif upper.startswith("NA"):
             element = elem.sodium
-        elif upper.startswith('MG'):
+        elif upper.startswith("MG"):
             element = elem.magnesium
-        elif upper.startswith('BE'):
+        elif upper.startswith("BE"):
             element = elem.beryllium
-        elif upper.startswith('LI'):
+        elif upper.startswith("LI"):
             element = elem.lithium
-        elif upper.startswith('K'):
+        elif upper.startswith("K"):
             element = elem.potassium
-        elif upper.startswith('ZN'):
+        elif upper.startswith("ZN"):
             element = elem.zinc
-        elif residue_length == 1 and upper.startswith('CA'):
+        elif residue_length == 1 and upper.startswith("CA"):
             element = elem.calcium
 
         # TJL has edited this. There are a few issues here. First,
@@ -655,15 +752,15 @@ class PDBTrajectoryFile(object):
         # below. Second, there is additional parsing code in
         # pdbstructure.py, and I am unsure why it doesn't get used
         # here...
-        elif residue_length > 1 and upper.startswith('CE'):
+        elif residue_length > 1 and upper.startswith("CE"):
             element = elem.carbon  # (probably) not Celenium...
-        elif residue_length > 1 and upper.startswith('CD'):
+        elif residue_length > 1 and upper.startswith("CD"):
             element = elem.carbon  # (probably) not Cadmium...
-        elif residue_name in ['TRP', 'ARG', 'GLN', 'HIS'] and upper.startswith('NE'):
+        elif residue_name in ["TRP", "ARG", "GLN", "HIS"] and upper.startswith("NE"):
             element = elem.nitrogen  # (probably) not Neon...
-        elif residue_name in ['ASN'] and upper.startswith('ND'):
+        elif residue_name in ["ASN"] and upper.startswith("ND"):
             element = elem.nitrogen  # (probably) not ND...
-        elif residue_name == 'CYS' and upper.startswith('SG'):
+        elif residue_name == "CYS" and upper.startswith("SG"):
             element = elem.sulfur  # (probably) not SG...
         else:
             try:
@@ -679,8 +776,8 @@ class PDBTrajectoryFile(object):
 
     @staticmethod
     def _parseResidueAtoms(residue, map):
-        for atom in residue.findall('Atom'):
-            name = atom.attrib['name']
+        for atom in residue.findall("Atom"):
+            name = atom.attrib["name"]
             for id in atom.attrib:
                 map[atom.attrib[id]] = name
 
@@ -695,10 +792,10 @@ class PDBTrajectoryFile(object):
 
     def __len__(self):
         "Number of frames in the file"
-        if str(self._mode) != 'r':
+        if str(self._mode) != "r":
             raise NotImplementedError('len() only available in mode="r" currently')
         if not self._open:
-            raise ValueError('I/O operation on closed file')
+            raise ValueError("I/O operation on closed file")
         return len(self._positions)
 
 
@@ -708,8 +805,9 @@ def _format_83(f):
     gracefully degrade the precision by lopping off some of the decimal
     places. If it's much too large, we throw a ValueError"""
     if -999.999 < f < 9999.999:
-        return '%8.3f' % f
+        return "%8.3f" % f
     if -9999999 < f < 99999999:
-        return ('%8.3f' % f)[:8]
-    raise ValueError('coordinate "%s" could not be represnted '
-                     'in a width-8 field' % f)
+        return ("%8.3f" % f)[:8]
+    raise ValueError(
+        'coordinate "%s" could not be represnted ' "in a width-8 field" % f,
+    )
