@@ -25,40 +25,44 @@
 This code is new and should be considered __unstable__
 """
 
-##############################################################################
-# Imports
-##############################################################################
-
-from __future__ import print_function, division
-import numpy as np
-from itertools import combinations
-from mdtraj.utils.six.moves import filter, xrange  # itertools
 import logging
+from itertools import combinations
+
+import numpy as np
 
-from mdtraj.geometry.distance import compute_distances
-from mdtraj.geometry.dihedral import compute_dihedrals
 from mdtraj.geometry.angle import compute_angles
+from mdtraj.geometry.dihedral import compute_dihedrals
+from mdtraj.geometry.distance import compute_distances
 from mdtraj.utils import import_
+from mdtraj.utils.six.moves import filter, xrange  # itertools
 
 # these are covalent radii taken from the crystalographic data in nm
 # Dalton Trans., 2008, 2832-2838, DOI: 10.1039/B801115J
 # http://pubs.rsc.org/en/Content/ArticleLanding/2008/DT/b801115j
-COVALENT_RADII = {'C': 0.0762, 'N': 0.0706, 'O': 0.0661, 'H': 0.031,
-                  'S': 0.105}
+COVALENT_RADII = {
+    "C": 0.0762,
+    "N": 0.0706,
+    "O": 0.0661,
+    "H": 0.031,
+    "S": 0.105,
+}
 logger = logging.getLogger(__name__)
 
-__all__ = ['get_redundant_internal_coordinates',
-           'get_nonredundant_internal_coordinates', 'get_connectivity',
-           'get_bond_connectivity', 'get_angle_connectivity',
-           'get_dihedral_connectivity', 'get_wilson_B', 'get_bond_derivs',
-           'get_angle_derivs', 'get_dihedral_derivs']
+__all__ = [
+    "get_redundant_internal_coordinates",
+    "get_nonredundant_internal_coordinates",
+    "get_connectivity",
+    "get_bond_connectivity",
+    "get_angle_connectivity",
+    "get_dihedral_connectivity",
+    "get_wilson_B",
+    "get_bond_derivs",
+    "get_angle_derivs",
+    "get_dihedral_derivs",
+]
 
 
-################################################################################
 # Get actual coordinates
-################################################################################
-
-
 def get_redundant_internal_coordinates(trajectory, **kwargs):
     """Compute internal coordinates from the cartesian coordinates
 
@@ -92,10 +96,10 @@ def get_redundant_internal_coordinates(trajectory, **kwargs):
         internal_coords[i,j] gives the jth coordinate for the ith frame.
     """
 
-    if 'ibonds' in kwargs and 'iangles' in kwargs and 'idihedrals' in kwargs:
-        ibonds = kwargs['ibonds']
-        iangles = kwargs['iangles']
-        idihedrals = kwargs['idihedrals']
+    if "ibonds" in kwargs and "iangles" in kwargs and "idihedrals" in kwargs:
+        ibonds = kwargs["ibonds"]
+        iangles = kwargs["iangles"]
+        idihedrals = kwargs["idihedrals"]
     else:
         ibonds, iangles, idihedrals = get_connectivity(trajectory)
 
@@ -106,10 +110,10 @@ def get_redundant_internal_coordinates(trajectory, **kwargs):
     # instead of three times if xyzlist really does need to be reordered
     # in memory
 
-    xyzlist = np.array(trajectory.xyz, dtype=np.float32, order='c')
-    ibonds = np.array(ibonds, dtype=np.int32, order='c')
-    iangles = np.array(iangles, dtype=np.int32, order='c')
-    idihedrals = np.array(idihedrals, dtype=np.int32, order='c')
+    xyzlist = np.array(trajectory.xyz, dtype=np.float32, order="c")
+    ibonds = np.array(ibonds, dtype=np.int32, order="c")
+    iangles = np.array(iangles, dtype=np.int32, order="c")
+    idihedrals = np.array(idihedrals, dtype=np.int32, order="c")
 
     b = compute_distances(xyzlist, ibonds)
     a = compute_angles(xyzlist, iangles)
@@ -183,8 +187,12 @@ def get_nonredundant_internal_coordinates(trajectory, conformation, get_operator
 
     ibonds, iangles, idihedrals = get_connectivity(conformation)
 
-    B = get_wilson_B(conformation, ibonds=ibonds, iangles=iangles,
-                     idihedrals=idihedrals)
+    B = get_wilson_B(
+        conformation,
+        ibonds=ibonds,
+        iangles=iangles,
+        idihedrals=idihedrals,
+    )
     # reshape from (n_redundant, n_atoms, 3) to (n_redundant, n_atoms*3)
     B = B.reshape((B.shape[0], B.shape[1] * B.shape[2]))
 
@@ -196,11 +204,18 @@ def get_nonredundant_internal_coordinates(trajectory, conformation, get_operator
     activespace = eigenvectors[:, np.where(eigenvalues > 1e-10)[0]]
 
     if activespace.shape[1] != 3 * trajectory.xyz.shape[1] - 6:
-        logger.error('Active eigenspace is %dd, but 3*N - 6 = %d',
-                     activespace.shape[1], 3 * trajectory.xyz.shape[1] - 6)
+        logger.error(
+            "Active eigenspace is %dd, but 3*N - 6 = %d",
+            activespace.shape[1],
+            3 * trajectory.xyz.shape[1] - 6,
+        )
 
-    redundant = get_redundant_internal_coordinates(trajectory, ibonds=ibonds,
-                                                   iangles=iangles, idihedrals=idihedrals)
+    redundant = get_redundant_internal_coordinates(
+        trajectory,
+        ibonds=ibonds,
+        iangles=iangles,
+        idihedrals=idihedrals,
+    )
 
     if get_operator:
         return np.dot(redundant, activespace), activespace, ibonds, iangles, idihedrals
@@ -208,10 +223,8 @@ def get_nonredundant_internal_coordinates(trajectory, conformation, get_operator
         return np.dot(redundant, activespace)
 
 
-################################################################################
-# Compte the connectivity, getting lists of atom indices which form bonds, bond
+# Comupte the connectivity, getting lists of atom indices which form bonds, bond
 # angles and dihedrals
-################################################################################
 def get_connectivity(conf):
     """Get the indices of all the bonds/angles/dihedrals
 
@@ -265,22 +278,23 @@ def get_bond_connectivity(conf):
     Bakken and Helgaker, JCP Vol. 117, Num. 20 22 Nov. 2002
     http://folk.uio.no/helgaker/reprints/2002/JCP117b_GeoOpt.pdf
     """
-    from scipy.spatial.distance import squareform, pdist
+    from scipy.spatial.distance import pdist, squareform
 
     xyz = conf.xyz[0, :, :]
     n_atoms = xyz.shape[0]
 
-    elements = np.zeros(n_atoms, dtype='S1')
+    elements = np.zeros(n_atoms, dtype="S1")
     atom_names = [a.name for a in conf.top.atoms()]
     for i in xrange(n_atoms):
         # name of the element that is atom[i]
         # take the first character of the AtomNames string,
         # after stripping off any digits
 
-        elements[i] = atom_names[i].strip('123456789 ')[0]
-        if not elements[i] in COVALENT_RADII.keys():
-            raise ValueError("I don't know about this AtomName: {}".format(
-                atom_names[i]))
+        elements[i] = atom_names[i].strip("123456789 ")[0]
+        if elements[i] not in COVALENT_RADII.keys():
+            raise ValueError(
+                f"I don't know about this AtomName: {atom_names[i]}",
+            )
 
     distance_mtx = squareform(pdist(xyz))
     connectivity = []
@@ -313,13 +327,13 @@ def get_angle_connectivity(ibonds):
         n_angles x 3 array of indices, where each row is the index of three
         atoms m,n,o such that n is bonded to both m and o.
     """
-    nx = import_('networkx')
+    nx = import_("networkx")
     graph = nx.from_edgelist(ibonds)
     n_atoms = graph.number_of_nodes()
     iangles = []
 
     for i in xrange(n_atoms):
-        for (m, n) in combinations(graph.neighbors(i), 2):
+        for m, n in combinations(graph.neighbors(i), 2):
             # so now the there is a bond angle m-i-n
             iangles.append((m, i, n))
 
@@ -342,7 +356,7 @@ def get_dihedral_connectivity(ibonds):
         All sets of 4 atoms A,B,C,D such that A is bonded to B, B is bonded
         to C, and C is bonded to D
     """
-    nx = import_('networkx')
+    nx = import_("networkx")
     graph = nx.from_edgelist(ibonds)
     n_atoms = graph.number_of_nodes()
     idihedrals = []
@@ -361,18 +375,13 @@ def get_dihedral_connectivity(ibonds):
     return np.array(idihedrals)
 
 
-################################################################################
-# Compute derivatives of internal coordinates w.r.t to cartesian coordinates
-# these methods only operate on a single frame
-################################################################################
-
 def get_wilson_B(conformation, **kwargs):
     """Calculate the Wilson B matrix, which collects the derivatives of the
     redundant internal coordinates w/r/t the cartesian coordinates.
 
     .. math::
 
-        B_{ij} = \frac{\partial q_i}{\partial x_j}
+        B_{ij} = \frac{\\partial q_i}{\\partial x_j}
 
     where :math:`q_i` are the internal coorindates and the :math:`x_j` are
     the Cartesian displacement coordinates of the atoms.
@@ -401,10 +410,10 @@ def get_wilson_B(conformation, **kwargs):
         of internal coordinate`q_i` with respect the cartesian coordinate which
         is the `k`-th dimension (xyz) of the `j`-th atom.
     """
-    if 'ibonds' in kwargs and 'iangles' in kwargs and 'idihedrals' in kwargs:
-        ibonds = kwargs['ibonds']
-        iangles = kwargs['iangles']
-        idihedrals = kwargs['idihedrals']
+    if "ibonds" in kwargs and "iangles" in kwargs and "idihedrals" in kwargs:
+        ibonds = kwargs["ibonds"]
+        iangles = kwargs["iangles"]
+        idihedrals = kwargs["idihedrals"]
     else:
         ibonds, iangles, idihedrals = get_connectivity(conformation)
 
@@ -479,9 +488,9 @@ def get_angle_derivs(xyz, iangles):
     vector2 = np.array([-1, 1, 1]) / np.sqrt(3)
 
     for a, (m, o, n) in enumerate(iangles):
-        u_prime = (xyz[m] - xyz[o])
+        u_prime = xyz[m] - xyz[o]
         u_norm = np.linalg.norm(u_prime)
-        v_prime = (xyz[n] - xyz[o])
+        v_prime = xyz[n] - xyz[o]
         v_norm = np.linalg.norm(v_prime)
         u = u_prime / u_norm
         v = v_prime / v_norm
@@ -533,9 +542,9 @@ def get_dihedral_derivs(xyz, idihedrals):
     derivatives = np.zeros((n_dihedrals, n_atoms, 3))
 
     for d, (m, o, p, n) in enumerate(idihedrals):
-        u_prime = (xyz[m] - xyz[o])
-        w_prime = (xyz[p] - xyz[o])
-        v_prime = (xyz[n] - xyz[p])
+        u_prime = xyz[m] - xyz[o]
+        w_prime = xyz[p] - xyz[o]
+        v_prime = xyz[n] - xyz[p]
 
         u_norm = np.linalg.norm(u_prime)
         w_norm = np.linalg.norm(w_prime)
